### xPDF50

Given a URL of Harvard's CS50 web page containing a project, a problem or lecture notes xPDF50 outputs a clean PDF file of that project, problem, or notes.

> Installation

     $ pip install xPDF50

Make sure to provide a URL of a cs50.harvard.edu page containing a project, a problem or lecture notes.

> Usage

     $ xPDF50 url

Please note that following modules are 'required' for xPDF50 to work. (Install them from Pypi using pip)

* Pillow
* requests
* xhtml2pdf

*** Important: Recommends only to be used within CS50's labs and codespaces. You may have to install 'C++ build tools', otherwise.

     



